@@ -6,10 +6,3 @@ from .ArticlesAPI import ArticlesAPI
 from .Url2Html import Url2Html
 from .nickname2biz import nickname2biz
 from .GetUrls import PCUrls, MobileUrls
-
-try:
-    from .ReadOutfile import Reader
-except Exception:
-    print("not use mitmproxy")
-
-__version__ = "0.4.5"
